@@ -98,17 +98,21 @@ def calculate_azimuth_and_elevation_angle(
     latitude: float, longitude: float, datestamps: [datetime]
 ) -> pd.DataFrame:
     """
-    Calculation the azimuth angle, and the elevation angle for several datetamps, but for one specific osgb location
+    Calculation the azimuth angle, and the elevation angle for several datetamps.
 
-    More details see: https://www.celestis.com/resources/faq/what-are-the-azimuth-and-elevation-of-a-satellite/
+    But for one specific osgb location
+
+    More details see:
+    https://www.celestis.com/resources/faq/what-are-the-azimuth-and-elevation-of-a-satellite/
 
     Args:
         latitude: latitude of the pv site
         longitude: longitude of the pv site
-        datestamps: list of datestamps to calculate the sun angles. i.e the sun moves from east to west in the day.
+        datestamps: list of datestamps to calculate the sun angles. i.e the sun moves from east to
+            west in the day.
 
-    Returns: Pandas data frame with the index the same as 'datestamps', with columns of "elevation" and "azimuth" that
-    have been calculate.
+    Returns: Pandas data frame with the index the same as 'datestamps', with columns of
+    "elevation" and "azimuth" that have been calculate.
 
     """
     # get the solor position
